# Player Metrics: 
This repository contains the source code for the <em>#StrictlyBytheNumbers</em> PlayerMetric module. The PlayerMetric module attempts to provide key player metrics that could be then leveraged in a variety ways for a multitude of downstream baskebtall applications"

## requirements

- 1.) Install python package depedencies.
```shell
$ pip install -r requirements.txt
```
